==> haskell-cheapskate-0.1.1-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.1
id: cheapskate-0.1.1-KyqgRaIkuVjELswiGOtPTm
key: cheapskate-0.1.1-KyqgRaIkuVjELswiGOtPTm
license: BSD3
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
abi: 3267c47e6ba36e450478b660224510e8
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cheapskate-0.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/cheapskate-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/cheapskate-0.1.1
hs-libraries: HScheapskate-0.1.1-KyqgRaIkuVjELswiGOtPTm
depends:
    base-4.10.0.0 containers-0.5.10.2 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    xss-sanitize-0.3.5.7-CPN9YNtobCt7QpV2Zbtlk0
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    syb-0.7-2rRPTNxBP6YFePrCXw4i2o
    uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ deepseq-1.4.3.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             xss-sanitize-0.3.5.7-CPN9YNtobCt7QpV2Zbtlk0=7bce062845170c55bf1cf13951abfac1
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ=3300bc881e9fb75483828891b71f16f8
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.1-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.1
id: cheapskate-0.1.1-43164Jo7h66jjSnB1g3cA
key: cheapskate-0.1.1-43164Jo7h66jjSnB1g3cA
license: BSD3
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
abi: 41c8f8d52051564a359e3098dca1c022
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cheapskate-0.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/cheapskate-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/cheapskate-0.1.1
hs-libraries: HScheapskate-0.1.1-43164Jo7h66jjSnB1g3cA
depends:
    base-4.10.0.0 containers-0.5.10.2 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    xss-sanitize-0.3.5.7-CPN9YNtobCt7QpV2Zbtlk0
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    syb-0.7-2rRPTNxBP6YFePrCXw4i2o
    uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ deepseq-1.4.3.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             xss-sanitize-0.3.5.7-CPN9YNtobCt7QpV2Zbtlk0=7bce062845170c55bf1cf13951abfac1
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ=3300bc881e9fb75483828891b71f16f8
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
